diff --git a/.eslintignore b/.eslintignore
new file mode 100644
index 0000000..f59ec20
--- /dev/null
+++ b/.eslintignore
@@ -0,0 +1 @@
+*
\ No newline at end of file
diff --git a/assets/js/site.js b/assets/js/site.js
index 6e43228..4c82e91 100644
--- a/assets/js/site.js
+++ b/assets/js/site.js
@@ -11,6 +11,7 @@ var mojangServicesUpdater;
var sortServersTask;
var currentServerHover;
+var faviconSize = 64;
function updateServerStatus(lastEntry) {
var info = lastEntry.info;
@@ -413,7 +414,7 @@ $(document).ready(function() {
class: 'server',
'server-id': safeNameCopy,
html: '
\
-
\
+
\
\
\
\
diff --git a/lib/ping.js b/lib/ping.js
index c1d6d48..3d53087 100644
--- a/lib/ping.js
+++ b/lib/ping.js
@@ -11,15 +11,22 @@ function pingMinecraftPC(host, port, timeout, callback, version) {
if (err) {
callback(err, null);
} else {
- // Remap our JSON into our custom structure.
+ // Remap our JSON into our custom structure.
+ var favicon;
+
+ // Ensure the returned favicon is a data URI
+ if (res.favicon.indexOf('data:image/') === 0) {
+ favicon = res.favicon;
+ }
+
callback(null, {
players: {
- online: res.players.online,
- max: res.players.max
+ online: parseInt(res.players.online),
+ max: parseInt(res.players.max)
},
- version: res.version.protocol,
+ version: parseInt(res.version.protocol),
latency: util.getCurrentTimeMs() - startTime,
- favicon: res.favicon
+ favicon
});
}
}, timeout, version);